from __future__ import annotations
import os
import sys
from datetime import datetime


def add_python_path(project_dir: str, my_file: str) -> (str, str):
    """
    @param project_dir: enclosing path node (e.g., LogicBank
    @param my_file: callers __file__ variable
    @result (path_was_fixed, path)

    """
    target_last_node = project_dir.lower()
    current_path = os.path.abspath(os.path.dirname(my_file))
    each_last_node = ""
    while each_last_node != target_last_node:
        each_last_node = os.path.basename(os.path.normpath(current_path))
        each_last_node = each_last_node.lower()
        if each_last_node != target_last_node:
            current_path = os.path.dirname(current_path)
            if current_path == "/":
                raise Exception("project_dir not found: " + target_last_node)

    sys_path = ""
    required_path_present = False
    for each_last_node in sys.path:
        sys_path += each_last_node + "\n"
        if each_last_node == current_path:
            required_path_present = True
    if not required_path_present:
        result_was_fixed = "Fixing path (so can run from terminal)"
        sys.path.append(current_path)
    else:
        pass
        result_was_fixed = "NOT Fixing path (default PyCharm, set in VSC Launch Config)"
    return result_was_fixed, get_run_environment_info()


def get_sys_path():
    """
    :return: readable, multi-line output of Python Path
    """
    sys_path = ""
    for each_node in sys.path:
        sys_path += each_node + "\n"
    return sys_path


def get_run_environment_info():
    """
    @return: readable, multi-line output of Python environment
    """
    cwd = os.getcwd()   # eg, /Users/val/dev/logicbank/nw/tests
    run_environment_info = "Run Environment info...\n\n"
    run_environment_info += " Current Working Directory: " + cwd + "\n\n"
    run_environment_info += "sys.path: (Python imports)\n" + get_sys_path() + "\n"
    run_environment_info += "From: " + sys.argv[0] + "\n\n"
    run_environment_info += "Using Python: " + sys.version + "\n\n"
    run_environment_info += "At: " + str(datetime.now()) + "\n\n"
    return run_environment_info

if __name__ == "__main__":
    # execute only if run as a script
    print("\nRunning, sys_path:\n" + get_sys_path())
    add_python_path(project_dir="LogicBankUtils", my_file=__file__)
    print("\n\nCompleted: result is\n" + get_sys_path())


import io
import os
import re

from setuptools import find_packages, setup

def fpath(name):
    return os.path.join(os.path.dirname(__file__), name)


def read(fname):
    return open(fpath(fname)).read()


def desc():
    return read("README.rst")


project_urls = {
  'Docs': 'https://github.com/valhuber/logicbankutils/wiki'
}

setup(
    name="logicbankutils",
    version="0.3.0",
    url="https://github.com/valhuber/logicbankutils",
    license="BSD",
    author="Val Huber",
    author_email="valjhuber@gmail.com",
    project_urls=project_urls,
    description=(
        "Utility functions for LogicBase"
    ),
    long_description=desc(),
    long_description_content_type="text/x-rst",
    packages=['logic_bank_utils'],
    package_data={"": ["LICENSE"]},
    include_package_data=True,
    zip_safe=False,
    platforms="any",
    install_requires=[],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires="~=3.8"
)